==> cloudpos-common-classes-1.7-20210118.052708-73.jar: com/floreantpos/util/DatabaseVersionHistory.java <==
package com.floreantpos.util;

public class DatabaseVersionHistory {
	/**
	 * Version 279:
	 * Added 'customPaymentId' field in PosTransaction.	 
	 * Added 'PROPERTIES' field in VirtualPrinter.	
	 * 
	 * Version 278:
	 * Added outletId field in OnlineCategory, OnlineGroup and OnlineItem.	
	 * 
	 * Version 277:
	 * Added 'DELETED' field in PayoutReason.	
	 * 
	 * Version 276:
	 * Added price and imageId in OnlineItem.
	 *
	 * Version 275:
	 * Added model OnlineCategory, OnlineGroup and OnlineItem.
	 * 
	 * Version 274:
	 * Added 'reseller' and 'commission' property in Customer.
	 * 
	 * Version 273:
	 * Added 'demoStore' and 'testStore' property in OnlineStore.
	 * 
	 * Version 272:
	 * Added 'sticky' and 'featured' property in OnlineStore.
	 * 
	 * Version 271:
	 * Added 'minQuantity','maxQuantity','jumpGroup','autoShow' ,'properties' and modifierPages field in ModifierGroup.	 
	 * Added 'MODIFIER_SPEC_MODIFIER_GROUP_ID' and 'MODIFIER_GROUP_ID' in MenuItemModifierPage.
	 * 
	 * Version 270:
	 * Removed orderType property from PizzaPrice.
	 * 
	 * Version 269,
	 * Added isDefault, properties, orderType property in PizzaPrice.
	 * 
	 * Version 268:
	 * Added latitude, longitude field in DeliveryAddress.
	 * 
	 * Version 267:
	 * No change, just increase.
	 * 
	 * Version 266:
	 * Added enable, searchable, standalone properites in OnlineStore.
	 * 
	 * Version 265:
	 * Added name and deleted fields in DeliveryAddress.
	 * 
	 * Version 264:
	 * Added field 'source' in Ticket.
	 * 
	 * Version 263:
	 * Added field friendlyUrl in OnlineStore.
	 * 
	 * Version 261, 262:
	 * No change.
	 * 
	 * Version 260:
	 * Added field telephone in OnlineStore.
	 * 
	 * Version 259:
	 * Added model DeliveryZone.
	 * 
	 * Version 258:
	 * Added model OnlineOrder.
	 * Added fields addressLine3, phone, latitude, longitude in Address model.
	 * Added fields storeName, addressLine1, addressLine2, addressLine3, house, flatNo, type, street, city, state, zipCode, country, countryCode, latitude, longitude, telephone, adminEmail in Outlet model.
	 * 
	 * Version 257:
	 * Added property onlineOrderingEnable in MenuCategory.
	 * 
	 * Version 256:
	 * Increase length of ticket.deliveryAddress to 320 characters.
	 * 
	 * Version 255:
	 * Added fields city, state, zipCode, country, countryCode, properties in DeliveryAddress.
	 * 
	 * Version 254:
	 * Added model OrderHistory.
	 * 
	 * Version 253:
	 * Added property 'friendlyUid' in Store.
	 * 
	 * Version 252:
	 * Added model GlobalConfig.
	 * 
	 * Version 251:
	 * Added more fields in TempTicket.
	 * 
	 * Version 250:
	 * Added class TempTicket.
	 * 
	 * Version 249:
	 * Added 'featured' property in MenuItem.
	 * Added 'transactionSubType' in BalanceUpdateTransaction.
	 * 
	 * Version 248:
	 * Added 'properties' field in ImageResource.
	 * 
	 * Version 247:
	 * Added 'outletId' and 'deleted' fields in MenuPage
	 * 
	 * Version 246:
	 * Added 'cost' field in PizzaPrice
	 * 
	 * Version 245:
	 * Added 'deleted' field in DeliveryCharge, DeliveryInstruction
	 * 
	 * Version 244:
	 * Added 'cost' field in ComboItem
	 * 
	 * Version 243:
	 * Added paid field in TicketItem
	 * 
	 * Version 242:
	 * Added outletId field in CustomPayment, VoidItem
	 * 
	 * Version 241:
	 * Added feeAmount field in PosTransaction
	 * 
	 * Version 240:
	 * Added comboChild field in TicketItem
	 * 
	 * Version 239:
	 * Added data_version field in Ticket, TicketItem, PosTransaction
	 * 
	 * Version 237:
	 * Added taxExempt, vatAmount, vatRate field in TicketItem.
	 * 
	 * Version 235:
	 * Added discountApplicable, ticketDiscountApplicable, serviceChargeRefundable in MenuItem, TicketItem
	 * 
	 * Version 234:
	 * Added taxExemptAmount proper in TicketItem and TicketItemModifier.
	 * 
	 * Version 233:
	 * Add itemWasted field in TicketItem.
	 * 
	 * Version 232:
	 * Added model 'BalanceUpdateTransaction'.
	 * 
	 * Version 231:
	 * Added 'deleted' field in PriceTableItem.
	 * 
	 * Version 230:
	 * Added 'properties' field in AttendanceHistory, CashBreakdown, Discount, EmployeeInOutHistory, Shift.
	 * 
	 * Version 229:
	 * Outlet model modified
	 * 
	 * Version 228:
	 * Removed duplicate void items.
	 * 
	 * Version 227:
	 * Added resellerId, ownerId fields in Store model.
	 * 
	 * Version 226:
	 * Added 'unitCost' and 'total' field in InventoryClosingBalance.
	 * 
	 * Version 225:
	 * Added 'deleted' field in PurchaseOrder.
	 * 
	 * Version 224:
	 * Added 'properties' field in Gratuity.
	 * 
	 * Version 223:
	 * Added 'properties' field in Address.
	 * Added Store Rating model.
	 * 
	 * Version 222:
	 * Added 'deleted' field in Ticket and TicketItem.
	 * 
	 * Version 221:
	 * Added 'taxabale' and 'properties' fields in MenuModifier.
	 * 
	 * Version 220:
	 * Added 'phoneNo' and 'defaultAddress' fields in DeliveryAddress.
	 * 
	 * Version 219:
	 * Added 'deleted' property in VirtualPrinter.
	 * 
	 * Version 218:
	 * Added 'deleted' property in CronJob and Recipe.
	 * 
	 * Version 217:
	 * Added 'deleted' property in CustomPayment.
	 * 
	 * Version 216:
	 * Added 'deleted' property in AttendenceHistory,BookingInfo,GiftCard,MenuItemSize,PackagingUnit,PizzaCrust,PriceRule,PriceTable,TerminalType.
	 * 
	 * Version 215:
	 * Added model SiiopaCustomer
	 * 
	 * Version 214:
	 * Added 'enableOnlineOrdering' property in Store and MenuItem.
	 * 
	 * Version 213:
	 * Clean tickets received by mqtt.
	 * 
	 * Version 212:
	 * Added properties field in TerminalPrinters.
	 * 
	 * Version 211:
	 * Added createdByUserId field in Ticket.
	 * Added ticketId, transactionId field in ActionHistory.
	 * 
	 * Version 210:
	 * 
	 * Version 208:
	 * Changed VoidItem table menu_item_name column length to 255.
	 * 
	 * Version 207:
	 * Field length change in Customer, User, Reseller.
	 * 
	 * Version 205:
	 * Added property field in ComboItem and ComboGroup.
	 * 
	 * Version 204:
	 * Added property field in MenuItemModifierSpec.*
	 * 
	 * Version 203:
	 * Added property field in ShopFloor and ShopSeat.
	 * 
	 * Version 202:
	 * Added 'translatedName' in MenuItemModifierPageItem.
	 * 
	 * Version 201:
	 * Added 'properties' field in TicketItemModifier.
	 * 
	 * Version 200:
	 * Added orderTypeId in MenuPage.
	 * 
	 * Version 199:
	 * Added translatedName in MenuPageItem.
	 * 
	 * Version 198:
	 * Added Reseller model.
	 * 
	 * Version 196:
	 * Added field retailerId in Customer.
	 * 
	 * Version 193:
	 * Added 'canLoginInCloud' property in User.
	 * 
	 * Version 192:
	 * Added 'stripeId' property in Customer.
	 * 
	 * Version 190:
	 * Added 'deleted' property in ComboItem and ComboGroup.
	 * 
	 * Version 189:
	 * Added 'deleted' property in the following models: Address, CookingInstruction, Discount, MenuCategory, MenuGroup, MenuItem, Course, Shift, Tax, Terminal, User, VoidReason,
		UserType, Customer, CustomerGroup, ShopFloor, ShopTable, ShopTableType, PrinterGroup, OrderType, Currency, Department, MenuModifier, ModifierGroup, Multiplier, AttributeGroup, Attribute,
		SalesArea, TaxGroup, Outlet, InventoryLocation, InventoryUnit, InventoryVendor.
	 * 
	 * Version 188:
	 * Remove old constraints from database and restored constraints.
	 * 
	 * Version 187:
	 * Added email in User model
	 * 
	 * Version 186:
	 * Added longPassword in User and addressLine2 in Address model
	 * 
	 * Version 185:
	 * Converted properties from TERMINAL_PROPERTIES to EXTRA_PROPERTIES as JSON in Terminal model
	 * 
	 * Version 184:
	 * Added 'extraProperties' property in Terminal
	 * Added 'visible' property in MenuPageItem
	 * 
	 * Version 183:
	 * Added property field in ShopTable.
	 * 
	 * Version 182:
	 * Added active field in CronJob.
	 * 
	 * Version 181:
	 * Added field defaultOutletId in Store.
	 * 
	 * Version 180:
	 * Added field 'markedCaptured' in PosTransaction.
	 * 
	 * Version 179:
	 * Added field feeAmount in ticket.
	 * 
	 * Version 178:
	 * Added model CronJob
	 * 
	 * Version 177:
	 * hasSyncError property added in Ticket model
	 * 
	 * Version 176:
	 * Added masterTerminal property added in terminal model.
	 * 
	 * Version 175:
	 * Added lastSyncTime field in models.
	 * 
	 * Version 174:
	 * Property field added in ShopTableStatus model
	 * 
	 * Version 172:
	 * Type, SubType, Property, TaxInServiceCHarge, ServiceChargeApplicable, billingRecordType properties added in TaxGroup model.
	 * 
	 * Version 171:
	 * Added PROPERTIES in following models:
	 * BookingInfo, CashDrawer, InventoryVendor, InventoryVendorItems, MenuCategory, MenuGroup, OrderType, Ticket{extraProperties}, 
	 * TicketItem, User, PosTransaction.
	 * 
	 * Version 170:
	 * Added menuItemId in MenuItemModifierSpec model.
	 * 
	 * Version 169:
	 * Customer name added in ShopTable model.
	 * 
	 * Version 168
	 * Added startHour,startMin,endHour,endMin field in model BookingInfo
	 * 
	 * Version 167:
	 * Foretees Customer model change.
	 * 
	 * Version 166:
	 * Added field serviceChargeApplicable in OrderType
	 * 
	 * Version 165
	 * Added startHour,startMin,endHour,endMin field in model shift
	 * 
	 * Version 163
	 * Add properties map in outlet.
	 * 
	 * Version 162
	 * Current Booking Info Id added Shop Table model
	 * 
	 * Version 161
	 * BTN_WIDTH and BTN_HEIGHT added in shopFloor, outletId added in shopTable, closed property added in BookingInfo
	 * 
	 * Version 160
	 * Time format is changed to UTC
	 * 
	 * Version 156:
	 * Added field outletId in several model classes.
	 * 
	 * Version 155:
	 * Added active field in model Customer.
	 * 
	 * Version 154:
	 * Added secretCode field in model Customer.
	 * 
	 * Version 153:
	 * Added new model SlideShowImage.
	 * 
	 * Version 152:
	 * Added SlideShowImage model added.
	 * 
	 * Version 151:
	 * Added field 'uuid' in Store.
	 * 
	 * Version 150:
	 * Added field 'lastUpdateTime' in several models.
	 * 
	 * Version 149:
	 * Added 'CLOUD_SYNCED' and 'HAS_SYNC_ERROR' field in MenuItem, MenuGroup, MenuCategory, MenuModifier, ModifierGroup
	 * 
	 * Version 148:
	 * Added 'CLOUD_SYNCED' and 'HAS_SYNC_ERROR' field in User, UserType, Department, Store, Customer, Tax, TaxGroup, OrderType
	 * 
	 * Version 147:
	 * Added 'deviceType' field in Terminal
	 * 
	 * Version 145:
	 * Added 'cloudSynced' property in StoreSession and CashDrawer
	 * 
	 * Version 144:
	 * Added 'toleranceAmount' field in CashDrawer
	 * 
	 * Version 143:
	 * Add outletId filed in PosTransaction
	 * 
	 * Version 141:
	 * Added storeSessionId field in GratuityPaymentHistory.
	 * 
	 * version 140:
	 * Added LAST_UPDATE_DATE field in MenuItemInventoryStatus.
	 * 
	 * Version 139:
	 * Several fields added in KitchenTicketItem.
	 * 
	 * Version 138:
	 * Added barcode field in InventoryStock.
	 * 
	 * Version 137:
	 * Added changeAmount field in PosTransaction.
	 * 
	 * Changes in version 136:
	 * Added toleranceAmount field in PosTransaction.
	 * 
	 * Changes in version 135:
	 * TicketItems is now list instead of bag.
	 * 
	 * Changes in version 134:
	 * Added 'PAYMENT_SYNCED_PERCENTAGE' in TicketItem
	 * 
	 * Changes in version 133:
	 * Added 'cost' in StockCountItem
	 * 
	 * Changes in version 132:
	 * Added 'courseName' in TicketItem and KitchenTicketItem
	 * 
	 *  Changes in version 131:
	 * Added property 'note' in PurchaseOrderItem and 'invoiceNumber','shipDate' in PurchaseOrder
	 * 
	 * Changes in version 130:
	 * Added property 'server' in PosTransaction
	 * 
	 * Changes in version 128:
	 * Added 'storeSession' property in Ticket and PosTransaction
	 * 
	 * Changes in version 127:
	 * Added 'serviceCharge' property in CashDrawer and PosTransaction
	 * 
	 * Changes in version 126:
	 * Added 'lastUpdateDate' property in Customer and MenuItem
	 * 
	 * Changes in version 125:
	 * Added 'serviceCharge' column in TicketItemModifier
	 * 
	 * Changes in version 124:
	 * Added customer list in PurchaseOrderIem.
	 * 
	 * Changes in version 123:
	 * Added field 'editablePrice' in MenuItem
	 * 
	 * Changes in version 122:
	 * Removed unchanged(0) type inventory transactions and converted to IN(1),OUT(-1) transaction
	 * 
	 * Changes in 119:
	 * Added column showOnKitDisplay in KitchenDisplay
	 * 
	 * Changes in version 117:
	 * Added 'note' field in ticket.
	 * 
	 * Changes in version 115:
	 * Added field 'memberType' in Customer.
	 * 
	 * Changes in version 114
	 * Added defaultRecipe in MenuItem.
	 * 
	 * Changes in version 113
	 * fields added in ComboItem model.
	 * 
	 * Changes in version 112
	 * ...
	 * 
	 * Changes in version 111
	 * Added smtpPort in 
	 * 
	 * Changes in version 110
	 * Added lastUpdateDate property in KitchenTicket
	 * 
	 * Changes in version 109:
	 * 1. Added cloudSyncd property in Ticket.
	 * 
	 * Changes in version 108:
	 * Add the following properties in PosTransaction:
	 * 	1. cloudSynced
	 * 	2. customerBalanceBefore
	 * 	3. customerBalanceAfter
	 * 
	 * Changes in version 107:
	 * Added "cloudSynced" column in TicketItem
	 * 
	 * Changes in version 106:
	 * Added "SHOW_PRINT_BTN" column in Terminal
	 */
	public final static int DATABASE_VERSION = 279;
}

==> cloudpos-common-classes-1.7-20210415.110141-166.jar: com/floreantpos/util/DatabaseVersionHistory.java <==
package com.floreantpos.util;

public class DatabaseVersionHistory {
	/**
	 * Version 287:
	 * Added ticketServiceCharge field in Ticket.
	 * 
	 * Version 286:
	 * Restored clockedIn column in User table.
	 * 
	 * Version 285:
	 * Added roundedAmount in PosTransaction.
	 * 
	 * Version 284:
	 * Updated customer active status (true).
	 * Added countryCode field in Outlet.
	 * Added createdTime field in Store.
	 * Added properties field in PurchaseOrderItem.
	 * Added member, lifeTimeMember, membershipType, membershipStartDate, membershipRenewDate, membershipExpiryDate, membershipActive fields in Customer.
	 * Added service, serviceType fields in MenuItem, TicketItem
	 * 
	 * Version 283:
	 * Increase length of StockCountItem.ITEM_NAME to 255 characters.
	 *  
	 * Version 282:
	 * Added field createdTime in Store.
	 * 
	 * Version 281:
	 * Increase length of PurchaseOrderItem.ITEM_NAME to 255 characters.
	 * 
	 * Version 280:
	 * Added notification model.	 
	 * 
	 * Version 279:
	 * Added 'customPaymentId' field in PosTransaction.	 
	 * Added 'PROPERTIES' field in VirtualPrinter.	
	 * 
	 * Version 278:
	 * Added outletId field in OnlineCategory, OnlineGroup and OnlineItem.	
	 * 
	 * Version 277:
	 * Added 'DELETED' field in PayoutReason.	
	 * 
	 * Version 276:
	 * Added price and imageId in OnlineItem.
	 *
	 * Version 275:
	 * Added model OnlineCategory, OnlineGroup and OnlineItem.
	 * 
	 * Version 274:
	 * Added 'reseller' and 'commission' property in Customer.
	 * 
	 * Version 273:
	 * Added 'demoStore' and 'testStore' property in OnlineStore.
	 * 
	 * Version 272:
	 * Added 'sticky' and 'featured' property in OnlineStore.
	 * 
	 * Version 271:
	 * Added 'minQuantity','maxQuantity','jumpGroup','autoShow' ,'properties' and modifierPages field in ModifierGroup.	 
	 * Added 'MODIFIER_SPEC_MODIFIER_GROUP_ID' and 'MODIFIER_GROUP_ID' in MenuItemModifierPage.
	 * 
	 * Version 270:
	 * Removed orderType property from PizzaPrice.
	 * 
	 * Version 269,
	 * Added isDefault, properties, orderType property in PizzaPrice.
	 * 
	 * Version 268:
	 * Added latitude, longitude field in DeliveryAddress.
	 * 
	 * Version 267:
	 * No change, just increase.
	 * 
	 * Version 266:
	 * Added enable, searchable, standalone properites in OnlineStore.
	 * 
	 * Version 265:
	 * Added name and deleted fields in DeliveryAddress.
	 * 
	 * Version 264:
	 * Added field 'source' in Ticket.
	 * 
	 * Version 263:
	 * Added field friendlyUrl in OnlineStore.
	 * 
	 * Version 261, 262:
	 * No change.
	 * 
	 * Version 260:
	 * Added field telephone in OnlineStore.
	 * 
	 * Version 259:
	 * Added model DeliveryZone.
	 * 
	 * Version 258:
	 * Added model OnlineOrder.
	 * Added fields addressLine3, phone, latitude, longitude in Address model.
	 * Added fields storeName, addressLine1, addressLine2, addressLine3, house, flatNo, type, street, city, state, zipCode, country, countryCode, latitude, longitude, telephone, adminEmail in Outlet model.
	 * 
	 * Version 257:
	 * Added property onlineOrderingEnable in MenuCategory.
	 * 
	 * Version 256:
	 * Increase length of ticket.deliveryAddress to 320 characters.
	 * 
	 * Version 255:
	 * Added fields city, state, zipCode, country, countryCode, properties in DeliveryAddress.
	 * 
	 * Version 254:
	 * Added model OrderHistory.
	 * 
	 * Version 253:
	 * Added property 'friendlyUid' in Store.
	 * 
	 * Version 252:
	 * Added model GlobalConfig.
	 * 
	 * Version 251:
	 * Added more fields in TempTicket.
	 * 
	 * Version 250:
	 * Added class TempTicket.
	 * 
	 * Version 249:
	 * Added 'featured' property in MenuItem.
	 * Added 'transactionSubType' in BalanceUpdateTransaction.
	 * 
	 * Version 248:
	 * Added 'properties' field in ImageResource.
	 * 
	 * Version 247:
	 * Added 'outletId' and 'deleted' fields in MenuPage
	 * 
	 * Version 246:
	 * Added 'cost' field in PizzaPrice
	 * 
	 * Version 245:
	 * Added 'deleted' field in DeliveryCharge, DeliveryInstruction
	 * 
	 * Version 244:
	 * Added 'cost' field in ComboItem
	 * 
	 * Version 243:
	 * Added paid field in TicketItem
	 * 
	 * Version 242:
	 * Added outletId field in CustomPayment, VoidItem
	 * 
	 * Version 241:
	 * Added feeAmount field in PosTransaction
	 * 
	 * Version 240:
	 * Added comboChild field in TicketItem
	 * 
	 * Version 239:
	 * Added data_version field in Ticket, TicketItem, PosTransaction
	 * 
	 * Version 237:
	 * Added taxExempt, vatAmount, vatRate field in TicketItem.
	 * 
	 * Version 235:
	 * Added discountApplicable, ticketDiscountApplicable, serviceChargeRefundable in MenuItem, TicketItem
	 * 
	 * Version 234:
	 * Added taxExemptAmount proper in TicketItem and TicketItemModifier.
	 * 
	 * Version 233:
	 * Add itemWasted field in TicketItem.
	 * 
	 * Version 232:
	 * Added model 'BalanceUpdateTransaction'.
	 * 
	 * Version 231:
	 * Added 'deleted' field in PriceTableItem.
	 * 
	 * Version 230:
	 * Added 'properties' field in AttendanceHistory, CashBreakdown, Discount, EmployeeInOutHistory, Shift.
	 * 
	 * Version 229:
	 * Outlet model modified
	 * 
	 * Version 228:
	 * Removed duplicate void items.
	 * 
	 * Version 227:
	 * Added resellerId, ownerId fields in Store model.
	 * 
	 * Version 226:
	 * Added 'unitCost' and 'total' field in InventoryClosingBalance.
	 * 
	 * Version 225:
	 * Added 'deleted' field in PurchaseOrder.
	 * 
	 * Version 224:
	 * Added 'properties' field in Gratuity.
	 * 
	 * Version 223:
	 * Added 'properties' field in Address.
	 * Added Store Rating model.
	 * 
	 * Version 222:
	 * Added 'deleted' field in Ticket and TicketItem.
	 * 
	 * Version 221:
	 * Added 'taxabale' and 'properties' fields in MenuModifier.
	 * 
	 * Version 220:
	 * Added 'phoneNo' and 'defaultAddress' fields in DeliveryAddress.
	 * 
	 * Version 219:
	 * Added 'deleted' property in VirtualPrinter.
	 * 
	 * Version 218:
	 * Added 'deleted' property in CronJob and Recipe.
	 * 
	 * Version 217:
	 * Added 'deleted' property in CustomPayment.
	 * 
	 * Version 216:
	 * Added 'deleted' property in AttendenceHistory,BookingInfo,GiftCard,MenuItemSize,PackagingUnit,PizzaCrust,PriceRule,PriceTable,TerminalType.
	 * 
	 * Version 215:
	 * Added model SiiopaCustomer
	 * 
	 * Version 214:
	 * Added 'enableOnlineOrdering' property in Store and MenuItem.
	 * 
	 * Version 213:
	 * Clean tickets received by mqtt.
	 * 
	 * Version 212:
	 * Added properties field in TerminalPrinters.
	 * 
	 * Version 211:
	 * Added createdByUserId field in Ticket.
	 * Added ticketId, transactionId field in ActionHistory.
	 * 
	 * Version 210:
	 * 
	 * Version 208:
	 * Changed VoidItem table menu_item_name column length to 255.
	 * 
	 * Version 207:
	 * Field length change in Customer, User, Reseller.
	 * 
	 * Version 205:
	 * Added property field in ComboItem and ComboGroup.
	 * 
	 * Version 204:
	 * Added property field in MenuItemModifierSpec.*
	 * 
	 * Version 203:
	 * Added property field in ShopFloor and ShopSeat.
	 * 
	 * Version 202:
	 * Added 'translatedName' in MenuItemModifierPageItem.
	 * 
	 * Version 201:
	 * Added 'properties' field in TicketItemModifier.
	 * 
	 * Version 200:
	 * Added orderTypeId in MenuPage.
	 * 
	 * Version 199:
	 * Added translatedName in MenuPageItem.
	 * 
	 * Version 198:
	 * Added Reseller model.
	 * 
	 * Version 196:
	 * Added field retailerId in Customer.
	 * 
	 * Version 193:
	 * Added 'canLoginInCloud' property in User.
	 * 
	 * Version 192:
	 * Added 'stripeId' property in Customer.
	 * 
	 * Version 190:
	 * Added 'deleted' property in ComboItem and ComboGroup.
	 * 
	 * Version 189:
	 * Added 'deleted' property in the following models: Address, CookingInstruction, Discount, MenuCategory, MenuGroup, MenuItem, Course, Shift, Tax, Terminal, User, VoidReason,
		UserType, Customer, CustomerGroup, ShopFloor, ShopTable, ShopTableType, PrinterGroup, OrderType, Currency, Department, MenuModifier, ModifierGroup, Multiplier, AttributeGroup, Attribute,
		SalesArea, TaxGroup, Outlet, InventoryLocation, InventoryUnit, InventoryVendor.
	 * 
	 * Version 188:
	 * Remove old constraints from database and restored constraints.
	 * 
	 * Version 187:
	 * Added email in User model
	 * 
	 * Version 186:
	 * Added longPassword in User and addressLine2 in Address model
	 * 
	 * Version 185:
	 * Converted properties from TERMINAL_PROPERTIES to EXTRA_PROPERTIES as JSON in Terminal model
	 * 
	 * Version 184:
	 * Added 'extraProperties' property in Terminal
	 * Added 'visible' property in MenuPageItem
	 * 
	 * Version 183:
	 * Added property field in ShopTable.
	 * 
	 * Version 182:
	 * Added active field in CronJob.
	 * 
	 * Version 181:
	 * Added field defaultOutletId in Store.
	 * 
	 * Version 180:
	 * Added field 'markedCaptured' in PosTransaction.
	 * 
	 * Version 179:
	 * Added field feeAmount in ticket.
	 * 
	 * Version 178:
	 * Added model CronJob
	 * 
	 * Version 177:
	 * hasSyncError property added in Ticket model
	 * 
	 * Version 176:
	 * Added masterTerminal property added in terminal model.
	 * 
	 * Version 175:
	 * Added lastSyncTime field in models.
	 * 
	 * Version 174:
	 * Property field added in ShopTableStatus model
	 * 
	 * Version 172:
	 * Type, SubType, Property, TaxInServiceCHarge, ServiceChargeApplicable, billingRecordType properties added in TaxGroup model.
	 * 
	 * Version 171:
	 * Added PROPERTIES in following models:
	 * BookingInfo, CashDrawer, InventoryVendor, InventoryVendorItems, MenuCategory, MenuGroup, OrderType, Ticket{extraProperties}, 
	 * TicketItem, User, PosTransaction.
	 * 
	 * Version 170:
	 * Added menuItemId in MenuItemModifierSpec model.
	 * 
	 * Version 169:
	 * Customer name added in ShopTable model.
	 * 
	 * Version 168
	 * Added startHour,startMin,endHour,endMin field in model BookingInfo
	 * 
	 * Version 167:
	 * Foretees Customer model change.
	 * 
	 * Version 166:
	 * Added field serviceChargeApplicable in OrderType
	 * 
	 * Version 165
	 * Added startHour,startMin,endHour,endMin field in model shift
	 * 
	 * Version 163
	 * Add properties map in outlet.
	 * 
	 * Version 162
	 * Current Booking Info Id added Shop Table model
	 * 
	 * Version 161
	 * BTN_WIDTH and BTN_HEIGHT added in shopFloor, outletId added in shopTable, closed property added in BookingInfo
	 * 
	 * Version 160
	 * Time format is changed to UTC
	 * 
	 * Version 156:
	 * Added field outletId in several model classes.
	 * 
	 * Version 155:
	 * Added active field in model Customer.
	 * 
	 * Version 154:
	 * Added secretCode field in model Customer.
	 * 
	 * Version 153:
	 * Added new model SlideShowImage.
	 * 
	 * Version 152:
	 * Added SlideShowImage model added.
	 * 
	 * Version 151:
	 * Added field 'uuid' in Store.
	 * 
	 * Version 150:
	 * Added field 'lastUpdateTime' in several models.
	 * 
	 * Version 149:
	 * Added 'CLOUD_SYNCED' and 'HAS_SYNC_ERROR' field in MenuItem, MenuGroup, MenuCategory, MenuModifier, ModifierGroup
	 * 
	 * Version 148:
	 * Added 'CLOUD_SYNCED' and 'HAS_SYNC_ERROR' field in User, UserType, Department, Store, Customer, Tax, TaxGroup, OrderType
	 * 
	 * Version 147:
	 * Added 'deviceType' field in Terminal
	 * 
	 * Version 145:
	 * Added 'cloudSynced' property in StoreSession and CashDrawer
	 * 
	 * Version 144:
	 * Added 'toleranceAmount' field in CashDrawer
	 * 
	 * Version 143:
	 * Add outletId filed in PosTransaction
	 * 
	 * Version 141:
	 * Added storeSessionId field in GratuityPaymentHistory.
	 * 
	 * version 140:
	 * Added LAST_UPDATE_DATE field in MenuItemInventoryStatus.
	 * 
	 * Version 139:
	 * Several fields added in KitchenTicketItem.
	 * 
	 * Version 138:
	 * Added barcode field in InventoryStock.
	 * 
	 * Version 137:
	 * Added changeAmount field in PosTransaction.
	 * 
	 * Changes in version 136:
	 * Added toleranceAmount field in PosTransaction.
	 * 
	 * Changes in version 135:
	 * TicketItems is now list instead of bag.
	 * 
	 * Changes in version 134:
	 * Added 'PAYMENT_SYNCED_PERCENTAGE' in TicketItem
	 * 
	 * Changes in version 133:
	 * Added 'cost' in StockCountItem
	 * 
	 * Changes in version 132:
	 * Added 'courseName' in TicketItem and KitchenTicketItem
	 * 
	 *  Changes in version 131:
	 * Added property 'note' in PurchaseOrderItem and 'invoiceNumber','shipDate' in PurchaseOrder
	 * 
	 * Changes in version 130:
	 * Added property 'server' in PosTransaction
	 * 
	 * Changes in version 128:
	 * Added 'storeSession' property in Ticket and PosTransaction
	 * 
	 * Changes in version 127:
	 * Added 'serviceCharge' property in CashDrawer and PosTransaction
	 * 
	 * Changes in version 126:
	 * Added 'lastUpdateDate' property in Customer and MenuItem
	 * 
	 * Changes in version 125:
	 * Added 'serviceCharge' column in TicketItemModifier
	 * 
	 * Changes in version 124:
	 * Added customer list in PurchaseOrderIem.
	 * 
	 * Changes in version 123:
	 * Added field 'editablePrice' in MenuItem
	 * 
	 * Changes in version 122:
	 * Removed unchanged(0) type inventory transactions and converted to IN(1),OUT(-1) transaction
	 * 
	 * Changes in 119:
	 * Added column showOnKitDisplay in KitchenDisplay
	 * 
	 * Changes in version 117:
	 * Added 'note' field in ticket.
	 * 
	 * Changes in version 115:
	 * Added field 'memberType' in Customer.
	 * 
	 * Changes in version 114
	 * Added defaultRecipe in MenuItem.
	 * 
	 * Changes in version 113
	 * fields added in ComboItem model.
	 * 
	 * Changes in version 112
	 * ...
	 * 
	 * Changes in version 111
	 * Added smtpPort in 
	 * 
	 * Changes in version 110
	 * Added lastUpdateDate property in KitchenTicket
	 * 
	 * Changes in version 109:
	 * 1. Added cloudSyncd property in Ticket.
	 * 
	 * Changes in version 108:
	 * Add the following properties in PosTransaction:
	 * 	1. cloudSynced
	 * 	2. customerBalanceBefore
	 * 	3. customerBalanceAfter
	 * 
	 * Changes in version 107:
	 * Added "cloudSynced" column in TicketItem
	 * 
	 * Changes in version 106:
	 * Added "SHOW_PRINT_BTN" column in Terminal
	 */
	public final static int DATABASE_VERSION = 287;
}
